package ru.mousecray.plants.blocks;

import java.util.Random;

import javax.annotation.Nullable;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.block.material.Material;
import net.minecraft.block.state.IBlockState;
import net.minecraft.util.math.AxisAlignedBB;
import net.minecraftforge.common.IShearable;
import ru.mousecray.plants.items.ListItems;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.util.NonNullList;
import net.minecraft.block.BlockBush;
import net.minecraft.block.SoundType;
import net.minecraft.item.ItemStack;
import net.minecraft.stats.StatList;
import net.minecraft.init.Blocks;
import net.minecraft.block.Block;
import net.minecraft.world.World;
import net.minecraft.init.Items;
import net.minecraft.item.Item;

public class CaveGrass extends BlockBush implements IShearable {
	
    protected static final AxisAlignedBB CAVE_GRASS_AABB = new AxisAlignedBB(0.09999999403953552D, 0.0D, 0.09999999403953552D, 0.8999999761581421D, 0.800000011920929D, 0.8999999761581421D);

    public CaveGrass() {
        super(Material.VINE);
        setSoundType(SoundType.PLANT);
        setUnlocalizedName("cave_grass");
        setRegistryName("cave_grass");
		setLightLevel(0.3F);
    }
    
    @Override
    //   boundingBox 
    public AxisAlignedBB getBoundingBox(IBlockState state, IBlockAccess source, BlockPos pos) {
       //   
       return CAVE_GRASS_AABB;
    }

    @Override
    //  ,    ,     
    public boolean isReplaceable(IBlockAccess world, BlockPos pos) {
        return true;
    }

    @Override
    //            
    public Item getItemDropped(IBlockState state, Random rand, int fortune) {
        return null;
    }

    @Override
    //     -
    public int quantityDroppedWithBonus(int fortune, Random random) {
        return 1 + random.nextInt(fortune * 2 + 1);
    }

    @Override
    // . ,  ,          
    public Block.EnumOffsetType getOffsetType() {
        return Block.EnumOffsetType.XYZ;
    }

    @Override
    //     
    public void harvestBlock(World world, EntityPlayer player, BlockPos pos, IBlockState state, @Nullable TileEntity te, ItemStack stack) {
        if (!world.isRemote && stack.getItem() == Items.SHEARS) {
            player.addStat(StatList.getBlockStats(this));
        }
        else {
            super.harvestBlock(world, player, pos, state, te, stack);
        }
    }
    @Override
    //,      .    
    public boolean canPlaceBlockAt(World world, BlockPos pos) {
        return world.getBlockState(pos).getBlock().isReplaceable(world, pos) && world.getBlockState(pos.down()).getBlock() == Blocks.STONE;
    }

    @Override
    //,  ,     ,  
    //  : "    ". ,   
    public boolean canBlockStay(World world, BlockPos pos, IBlockState state) {
        return world.getBlockState(pos.down()).getBlock() == Blocks.STONE;
    }

    @Override
    //    
    public boolean isShearable(ItemStack item, IBlockAccess world, BlockPos pos) {
        return true;
    }

    @Override
    // ,     
    public NonNullList onSheared(ItemStack item, IBlockAccess world, BlockPos pos, int fortune) {
        return NonNullList.withSize(1, new ItemStack(ListBlocks.CAVE_GRASS));
    }

    @Override
    //     .      ,   -  .
    //   ,    CAVE_SEEDS   
    public void getDrops(NonNullList<ItemStack> drops, IBlockAccess world, BlockPos pos, IBlockState state, int fortune) {
    	ItemStack seed = ItemStack.EMPTY;
    	
    	if (RANDOM.nextInt(30) != 0) {
            return;
        }
    	
    	if(world instanceof World) {
    		//,     "" 
    		if(!((World) world).canSeeSky(pos)) {
    			 seed = new ItemStack(ListItems.CAVE_SEEDS, fortune);
    		}
    		else {
    			seed = new ItemStack(Items.WHEAT_SEEDS, fortune);
    		}
    	}
    	
    	// 
        if (!seed.isEmpty()) {
            drops.add(seed);
        }
    }
}